@@ -1,7 +1,7 @@
 
 import unittest
 
-from mox3.mox import MoxTestBase
+from mox import MoxTestBase
 from gevent.socket import socket, SHUT_WR
 
 from slimta.policy.spamassassin import SpamAssassin, SpamAssassinError
